@@ -1,4 +1,4 @@
-/* $Id: main.c 27800 2008-09-10 11:03:20Z kelnos $ */
+/* $Id: main.c 28125 2008-10-09 21:46:58Z olivier $ */
 /*
  *  Copyright (c) 2008 Stephan Arts <stephan@xfce.org>
  *  Copyright (c) 2008 Jannis Pohlmann <jannis@xfce.org>
@@ -75,9 +75,11 @@ static const gchar* xft_rgba_array[] =
 };
 
 /* Option entries */
+static GdkNativeWindow opt_socket_id = 0;
 static gboolean opt_version = FALSE;
 static GOptionEntry option_entries[] =
 {
+    { "socket-id", 's', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_INT, &opt_socket_id, N_("Settings manager socket"), N_("SOCKET ID") },
     { "version", 'v', 0, G_OPTION_ARG_NONE, &opt_version, N_("Version information"), NULL },
     { NULL }
 };
@@ -203,6 +205,16 @@ cb_custom_dpi_check_button_toggled (GtkToggleButton *custom_dpi_toggle,
     }
 }
 
+static void
+cb_enable_event_sounds_check_button_toggled (GtkToggleButton *toggle, GtkWidget *button)
+{
+    gboolean active;
+
+    active = gtk_toggle_button_get_active (toggle);
+    gtk_widget_set_sensitive (button, active);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), active);
+}
+
 static void
 appearance_settings_load_icon_themes (GtkListStore *list_store,
                                       GtkTreeView  *tree_view)
@@ -375,7 +387,7 @@ appearance_settings_load_ui_themes (GtkListStore *list_store,
                     /* Get translated ui theme name and comment */
                     theme_name = xfce_rc_read_entry (index_file, "Name", file);
                     theme_comment = xfce_rc_read_entry (index_file, "Comment", NULL);
-                    
+
                     /* Escape the comment because tooltips are markup, not text */
                     comment_escaped = theme_comment ? g_markup_escape_text (theme_comment, -1) : NULL;
 
@@ -395,7 +407,7 @@ appearance_settings_load_ui_themes (GtkListStore *list_store,
                                     COLUMN_THEME_NAME, file,
                                     COLUMN_THEME_DISPLAY_NAME, theme_name,
                                     COLUMN_THEME_COMMENT, comment_escaped, -1);
-                                    
+
                 /* Cleanup */
                 g_free (comment_escaped);
 
@@ -508,8 +520,8 @@ appearance_settings_from_gtk_settings (void)
     }
 }
 
-static GtkWidget *
-appearance_settings_dialog_new_from_xml (GladeXML *gxml)
+static void
+appearance_settings_dialog_configure_widgets (GladeXML *gxml)
 {
     GtkListStore     *list_store;
     GtkCellRenderer  *renderer;
@@ -735,14 +747,32 @@ appearance_settings_dialog_new_from_xml (GladeXML *gxml)
     g_signal_connect (G_OBJECT (custom_dpi_check), "toggled", G_CALLBACK (cb_custom_dpi_check_button_toggled), custom_dpi_spin);
     g_signal_connect (G_OBJECT (custom_dpi_spin), "value-changed", G_CALLBACK (cb_custom_dpi_spin_value_changed), custom_dpi_check);
 
-    /* return dialog */
-    return glade_xml_get_widget (gxml, "appearance-settings-dialog");
+#ifdef ENABLE_SOUND_SETTINGS
+    /* Sounds */
+    GtkWidget *event_sounds_frame = glade_xml_get_widget (gxml, "event_sounds_frame");
+    GtkWidget *enable_event_sounds_check_button = glade_xml_get_widget (gxml, "enable_event_sounds_check_button");
+    GtkWidget *enable_input_feedback_sounds_button  = glade_xml_get_widget (gxml, "enable_input_feedback_sounds_button");
+
+    gtk_widget_show (event_sounds_frame);
+    g_signal_connect (G_OBJECT (enable_event_sounds_check_button),
+                      "toggled",
+                      G_CALLBACK (cb_enable_event_sounds_check_button_toggled),
+                      enable_input_feedback_sounds_button);
+    xfconf_g_property_bind (xsettings_channel, "/Net/EnableEventSounds", G_TYPE_BOOLEAN,
+                            G_OBJECT (enable_event_sounds_check_button), "active");
+    xfconf_g_property_bind (xsettings_channel, "/Net/EnableInputFeedbackSounds", G_TYPE_BOOLEAN,
+                            G_OBJECT (enable_input_feedback_sounds_button), "active");
+    gtk_widget_set_sensitive (GTK_BUTTON (enable_input_feedback_sounds_button),
+                              gtk_toggle_button_get_active (enable_event_sounds_check_button));
+#endif
 }
 
 gint
 main(gint argc, gchar **argv)
 {
     GtkWidget *dialog;
+    GtkWidget *plug;
+    GtkWidget *plug_child;
     GladeXML  *gxml;
     GError    *error = NULL;
 
@@ -800,17 +830,38 @@ main(gint argc, gchar **argv)
         gxml = glade_xml_new_from_buffer (appearance_dialog_glade, appearance_dialog_glade_length, NULL, NULL);
         if (G_LIKELY (gxml))
         {
-            /* build the dialog */
-            dialog = appearance_settings_dialog_new_from_xml (gxml);
+            appearance_settings_dialog_configure_widgets (gxml);
 
-            /* run the dialog */
-            gtk_dialog_run (GTK_DIALOG (dialog));
+            if (G_UNLIKELY (opt_socket_id == 0))
+            {
+                /* build the dialog */
+                dialog = glade_xml_get_widget (gxml, "appearance-settings-dialog");
+
+                /* run the dialog */
+                gtk_dialog_run (GTK_DIALOG (dialog));
+
+                /* destroy the dialog */
+                gtk_widget_destroy (dialog);
+            }
+            else
+            {
+                /* Create plug widget */
+                plug = gtk_plug_new (opt_socket_id);
+                gtk_widget_show (plug);
+
+                g_signal_connect (plug, "delete-event", G_CALLBACK (gtk_main_quit), NULL);
+
+                /* Get plug child widget */
+                plug_child = glade_xml_get_widget (gxml, "plug-child");
+                gtk_widget_reparent (plug_child, plug);
+                gtk_widget_show (plug_child);
+
+                /* Enter main loop */
+                gtk_main ();
+            }
 
             /* release the glade xml */
             g_object_unref (G_OBJECT (gxml));
-
-            /* destroy the dialog */
-            gtk_widget_destroy (dialog);
         }
 
         /* release the channel */
